package com.persagy.utils;

import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.core.JsonParseException;
import com.fasterxml.jackson.core.type.TypeReference;
import com.fasterxml.jackson.databind.JsonMappingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.IOException;


public class ItvJsonUtil {
    private static final Logger logger = LoggerFactory.getLogger(ItvJsonUtil.class);

    public static ObjectMapper mapper = new ObjectMapper();

    // 序列化时null字段不输出
    static {
        mapper.setDefaultPropertyInclusion(Include.NON_NULL);
    }

    /**
     * 将json字符串反序列号成对象
     *
     * @param <T>
     * @param json
     * @param clazz
     * @return
     */
    public static <T> T readValue(String json, Class<T> clazz) {
        try {
            return mapper.readValue(json, clazz);
        } catch (JsonParseException e) {
            logger.error("readValue exception", e);
            // e.printStackTrace();
        } catch (JsonMappingException e) {
            logger.error("readValue exception", e);
            // e.printStackTrace();
        } catch (IOException e) {
            logger.error("readValue exception", e);
            // e.printStackTrace();
        }

        return null;
    }

    /**
     * @param json
     * @param valueTypeRef
     * @return
     * @Title: readValue
     * @return: T
     */
    public static <T> T readValue(String json, TypeReference<T> valueTypeRef) {
        try {
            return mapper.readValue(json, valueTypeRef);
        } catch (JsonParseException e) {
            logger.error("readValue exception", e);
            // e.printStackTrace();
        } catch (JsonMappingException e) {
            logger.error("readValue exception", e);
            // e.printStackTrace();
        } catch (IOException e) {
            logger.error("readValue exception", e);
            // e.printStackTrace();
        }

        return null;
    }

    /**
     * 将对象序列号json字符串
     *
     * @param obj
     * @return
     */
    public static String writeValue(Object obj) {
        try {
            return mapper.writeValueAsString(obj);
        } catch (JsonParseException e) {
            logger.error("writeValue exception", e);
            // e.printStackTrace();
        } catch (JsonMappingException e) {
            logger.error("writeValue exception", e);
            // e.printStackTrace();
        } catch (IOException e) {
            logger.error("writeValue exception", e);
            // e.printStackTrace();
        }

        return null;
    }
}
